C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C****************************
C**     LDM_SET_TITLE      **
C****************************
C
C
CD-Doc:
C TITLe            SUBROUTINE LDM_SET_TITLE (VALSTR, IERR, ERRSTR)
CD-end
      SUBROUTINE LDM_SET_TITLE (VALSTR, IERR, ERRSTR)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Set value of string parameter TITLE
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      CHARACTER*(*) VALSTR
      INTEGER IERR
      CHARACTER*(*) ERRSTR

C  VALSTR    (R)   Title string (max 120 chars)
C  IERR      (W)   Error flag =0 OK
C                             =1 Invalid code or syntax error in string
C  ERRSTR    (W)   Error description string if error found
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C

C
C-------------------------------------------------------------------------------
C
      IERR = 0
      ERRSTR = ' '
      TITLE = VALSTR
      IS_TITLE = 1
      CH_TITLE = CH_MASK
      RETURN
      END
